/*=============================================================================
	UnExtAudio.h: UnrealEngine Extension audio subsystem header.
	
	Revision history:
		* Created by Sebastian Kaufel
=============================================================================*/

UNEXT_AUTOGENERATE_GUID(IID_IHumanHeadAudioSubsystem,0x0F6F5A69,0x57664C53,0xBFCCE32F,0x9E4B840B)

#ifndef UNEXT_GUID_ONLY

/*-----------------------------------------------------------------------------
	HumanHead AudioSubsystem interface.

	Motivation:
		Rune offers an extended UAudioSubsystem interface, which adds support
		for stopping a sound based on it's id and stopping all playing sounds
		at once. Additionally it adds PostRender() which is used to display
		statistics for games like Nerf who do not have this method in it's
		UAudioSubsystem interface declared.

	Reference implementation:
		* Rune.

	Notes:
		* StopSoundId() is implemented in DeusEx too.

	Further Notes:
		* Rune's and DeusEx's UnrealScript Actor.PlaySound() return an Id which
			is required for StopSoundId(). This id is generated using the following
			pattern: INT Id = GetIndex()*16 + Slot*2 + bNoOverride;
-----------------------------------------------------------------------------*/

struct IHumanHeadAudioSubsystem
{
	virtual UBOOL Init()=0;
	virtual void SetViewport( UViewport* Viewport )=0;
	virtual UBOOL Exec( const TCHAR* Cmd, FOutputDevice& Ar )=0;
	virtual void Update( FPointRegion Region, FCoords& Listener )=0;
	virtual void RegisterMusic( UMusic* Music )=0;
	virtual void RegisterSound( USound* Music )=0;
	virtual void UnregisterSound( USound* Sound )=0;
	virtual void UnregisterMusic( UMusic* Music )=0;
	virtual UBOOL PlaySound( AActor* Actor, INT Id, USound* Sound, FVector Location, FLOAT Volume, FLOAT Radius, FLOAT Pitch )=0;
	virtual void NoteDestroy( AActor* Actor )=0;
	virtual UBOOL GetLowQualitySetting()=0;
	virtual UViewport* GetViewport()=0;
	virtual void StopSoundId(INT Id)=0;
	virtual void StopAllSound(void)=0;
	virtual void RenderAudioGeometry( FSceneNode* Frame )=0;
	virtual void PostRender( FSceneNode* Frame )=0;
};

#endif // UNEXT_GUID_ONLY

/*----------------------------------------------------------------------------
	The End.
----------------------------------------------------------------------------*/
