/*=============================================================================
	UnExtRenDev.h: UnrealEngine Extension render device header.
	
	Revision history:
		* Created by Sebastian Kaufel
=============================================================================*/

UNEXT_AUTOGENERATE_GUID(IID_IKnowWonderRenderDevice,0xCB1E8908,0xEF4C4A4A,0xA5DD8D16,0x4F335D26)

#ifndef UNEXT_GUID_ONLY

/*-----------------------------------------------------------------------------
	KnowWonder RenderDevice interface.

	Motivation:
		Disney's Brother Bear offers an extended URenderDevice interface,
		which reflects a logical next step to clean up the rendering path
		with it's introduction of an interface to draw bunches of polygons,
		optional font rendering, distance fog and gamma handling.

	Reference implementation:
		* Disney's Brother Bear.

	Notes:
		* Might be (partially) implemented in KnowWonder's Harry Potter games.
-----------------------------------------------------------------------------*/

struct IKnowWonderRenderDevice
{
	virtual UBOOL Init( UViewport* InViewport, INT NewX, INT NewY, INT NewColorBytes, UBOOL Fullscreen )=0;
	virtual UBOOL SetRes( INT NewX, INT NewY, INT NewColorBytes, UBOOL Fullscreen )=0;
	virtual void Exit()=0;
	virtual void Flush( UBOOL AllowPrecache )=0;
	virtual UBOOL Exec( const TCHAR* Cmd, FOutputDevice& Ar )=0;
	virtual void Lock( FPlane FlashScale, FPlane FlashFog, FPlane ScreenClear, DWORD RenderLockFlags, BYTE* HitData, INT* HitSize )=0;
	virtual void Unlock( UBOOL Blit )=0;
	virtual void UpdateGamma()=0;
	virtual void RestoreGamma()=0;
	virtual void DrawComplexSurface( FSceneNode* Frame, FSurfaceInfo& Surface, FSurfaceFacet& Facet, DWORD, BYTE )=0;
	virtual INT MaxVertices()=0;
	virtual void DrawTriangles( FSceneNode* Frame, FTextureInfo& Info, FTransTexture** Pts, INT NumPts, _WORD* RemapTable, INT NumIndices, DWORD PolyFlags, class FSpanBuffer* Span )=0;
	virtual void DrawGouraudPolygon( FSceneNode* Frame, FTextureInfo& Info, FTransTexture** Pts, INT NumPts, DWORD PolyFlags, FSpanBuffer* Span )=0;
	virtual void DrawTile( FSceneNode* Frame, FTextureInfo& Info, FLOAT X, FLOAT Y, FLOAT XL, FLOAT YL, FLOAT U, FLOAT V, FLOAT UL, FLOAT VL, class FSpanBuffer* Span, FLOAT Z, FPlane Color, FPlane Fog, DWORD PolyFlags )=0;
	virtual void Draw3DLine( FSceneNode* Frame, FPlane Color, DWORD LineFlags, FVector OrigP, FVector OrigQ )=0;
	virtual void Draw2DClippedLine( FSceneNode* Frame, FPlane Color, DWORD LineFlags, FVector P1, FVector P2 )=0;
	virtual void Draw2DLine( FSceneNode* Frame, FPlane Color, DWORD LineFlags, FVector P1, FVector P2 )=0;
	virtual void Draw2DPoint( FSceneNode* Frame, FPlane Color, DWORD LineFlags, FLOAT X1, FLOAT Y1, FLOAT X2, FLOAT Y2, FLOAT Z )=0;
	virtual void ClearZ( FSceneNode* Frame )=0;
	virtual void PushHit( const BYTE* Data, INT Count )=0;
	virtual void PopHit( INT Count, UBOOL bForce )=0;
	virtual void GetStats( TCHAR* Result )=0;
	virtual void ReadPixels( FColor* Pixels )=0;
	virtual void EndFlash()=0;
	virtual void DrawStats( FSceneNode* Frame )=0;
	virtual void SetSceneNode( FSceneNode* Frame )=0;
	virtual void PrecacheTexture( FTextureInfo& Info, DWORD PolyFlags )=0;
	virtual void SetDistanceFog( UBOOL Enable, FLOAT FogStart, FLOAT FogEnd, FColor Color )=0;
	virtual void SetDistanceFogForceReset( UBOOL Enable )=0;
	virtual UBOOL GetDistanceFogForceReset()=0;
	virtual UBOOL HasNativeDrawString()=0;
	virtual void DrawString( DWORD, UFont* Font, INT& X, INT& Y, const TCHAR* Text, const FPlane& Color )=0;
};

#endif // UNEXT_GUID_ONLY

/*----------------------------------------------------------------------------
	The End.
----------------------------------------------------------------------------*/
